@@ -119,6 +119,8 @@ class StatusCode:
     IDENTITY_CERTIFICATION_OTHER = ("B0109", "身份证已认证")
     COMPANY_CERTIFICATION_PENDING = ("B0110", "企业正在认证")
     IDENTITY_CERTIFICATION_PENDING = ("B0111", "身份证正在认证")
+    COMPANY_NOT_CERTIFICATION = ("B0112", "企业未认证")
+    IDENTITY_NOT_CERTIFICATION = ("B0113", "身份证未认证")
     # B02开头的状态码
     STRIKE_RECOVERY = ("B0200", "系统容灾系统被触发")
     # B03开头的状态码
